---
name: "\U0001F4D6Documentation"
about: Suggest improvements or report missing/unclear documentation.

---

**Pre-check**
- [ ] I'm aware that I can [edit the docs](https://github.com/wswebcreation/multiple-cucumber-html-reporter-plugin) and submit a pull request

**Describe the improvement**

I'd like to report
- [ ] Unclear documentation
- [ ] A typo
- [ ] Missing documentation
- [ ] Other

**Description of the improvement / report**
A clear and concise description.
